@@ -1,7 +1,7 @@
 package App::ListOrgAnniversaries;
 
-our $DATE = '2015-03-30'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $DATE = '2015-04-01'; # DATE
+our $VERSION = '0.28'; # VERSION
 
 use 5.010;
 use strict;
@@ -152,24 +152,7 @@ startup script).
 
 _
     args    => {
-        files => {
-            schema  => ['array*' => {of => 'str*', min_len=>1}],
-            req     => 1,
-            pos     => 0,
-            greedy  => 1,
-            'x.schema.element_entity' => 'filename',
-        },
-        cache_dir => {
-            summary => 'Cache Org parse result',
-            schema  => ['str*'],
-            description => <<'_',
-
-Since Org::Parser can spend some time to parse largish Org files, this is an
-option to store the parse result. Caching is turned on if this argument is set.
-
-_
-            'x.schema.entity' => 'dirname',
-        },
+        %App::OrgUtils::common_args1,
         field_pattern => {
             summary => 'Field regex that specifies anniversaries',
             schema  => [str => {
@@ -196,16 +179,6 @@ _
                 'more than this number of days',
             schema  => ['int'],
         },
-        time_zone => {
-            summary => 'Will be passed to parser\'s options',
-            schema  => ['str'],
-            description => <<'_',
-
-If not set, TZ environment variable will be picked as default.
-
-_
-            #'x.schema.entity' => 'timezone',
-        },
         today => {
             summary => 'Assume today\'s date',
             schema  => [obj => isa=>'DateTime'],
@@ -242,7 +215,7 @@ sub list_org_anniversaries {
 
     my $sort  = $args{sort};
     my $tz    = $args{time_zone} // $ENV{TZ} // "UTC";
-    my $files = $args{files};
+    my $files = $args{file};
     my $f     = $args{field_pattern} // '';
     return [400, "Invalid field_pattern: $@"] unless eval { $f = qr/$f/i };
     $args{field_pattern} = $f;
@@ -298,7 +271,7 @@ App::ListOrgAnniversaries - List all anniversaries in Org files
 
 =head1 VERSION
 
-This document describes version 0.27 of App::ListOrgAnniversaries (from Perl distribution App-OrgUtils), released on 2015-03-30.
+This document describes version 0.28 of App::ListOrgAnniversaries (from Perl distribution App-OrgUtils), released on 2015-04-01.
 
 =head1 SYNOPSIS
 
@@ -358,7 +331,7 @@ Only show anniversaries that are due in this number of days.
 
 Field regex that specifies anniversaries.
 
-=item * B<files>* => I<array[str]>
+=item * B<file>* => I<array[str]>
 
 =item * B<has_tags> => I<array[str]>
 
@@ -410,20 +383,15 @@ Return value:  (any)
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUtils>.
+Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUtils>.=head1 SOURCE
 
-=head1 SOURCE
-
-Source repository is at L<https://github.com/sharyanto/perl-App-OrgUtils>.
-
-=head1 BUGS
+Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.=head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-OrgUtils>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
