@@ -1,7 +1,7 @@
 package App::ListOrgHeadlines;
 
-our $DATE = '2015-03-30'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $DATE = '2015-04-01'; # DATE
+our $VERSION = '0.28'; # VERSION
 
 use 5.010001;
 use strict;
@@ -157,24 +157,7 @@ $SPEC{list_org_headlines} = {
     v       => 1.1,
     summary => 'List all headlines in all Org files',
     args    => {
-        files => {
-            schema => ['array*' => of => 'str*', min_len=>1],
-            req    => 1,
-            pos    => 0,
-            greedy => 1,
-            'x.schema.element_entity' => 'filename',
-        },
-        cache_dir => {
-            schema => ['str*'],
-            summary => 'Cache Org parse result',
-            description => <<'_',
-
-Since Org::Parser can spend some time to parse largish Org files, this is an
-option to store the parse result. Caching is turned on if this argument is set.
-
-_
-            'x.schema.entity' => 'dirname',
-        },
+        %App::OrgUtils::common_args1,
         todo => {
             schema => ['bool'],
             summary => 'Only show headlines that are todos',
@@ -296,16 +279,6 @@ included.
 _
             links => ['minimum_priority', 'maximum_priority'],
         },
-        time_zone => {
-            schema => ['str'],
-            summary => 'Will be passed to parser\'s options',
-            description => <<'_',
-
-If not set, TZ environment variable will be picked as default.
-
-_
-            #'x.schema.entity' => 'timezone',
-        },
         today => {
             schema => [obj => isa=>'DateTime'],
             summary => 'Assume today\'s date',
@@ -344,7 +317,7 @@ sub list_org_headlines {
 
     my $sort  = $args{sort};
     my $tz    = $args{time_zone} // $ENV{TZ} // "UTC";
-    my $files = $args{files};
+    my $files = $args{file};
 
     $today = $args{today} // DateTime->today(time_zone => $tz);
 
@@ -425,7 +398,7 @@ App::ListOrgHeadlines - List all headlines in all Org files
 
 =head1 VERSION
 
-This document describes version 0.27 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2015-03-30.
+This document describes version 0.28 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2015-04-01.
 
 =head1 SYNOPSIS
 
@@ -474,7 +447,7 @@ if today is 2011-06-30 and due_in is set to 7, then todo item with due date
 than 7) but <2011-07-10 Sun +1y -14d> will (warning period 14 days is already
 passed by that time).
 
-=item * B<files>* => I<array[str]>
+=item * B<file>* => I<array[str]>
 
 =item * B<from_level> => I<int> (default: 1)
 
@@ -575,20 +548,15 @@ Return value:  (any)
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUtils>.
+Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUtils>.=head1 SOURCE
 
-=head1 SOURCE
-
-Source repository is at L<https://github.com/sharyanto/perl-App-OrgUtils>.
-
-=head1 BUGS
+Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.=head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-OrgUtils>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
