@@ -1,7 +1,7 @@
 package App::OrgUtils;
 
-our $DATE = '2015-03-30'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $DATE = '2015-04-01'; # DATE
+our $VERSION = '0.28'; # VERSION
 
 use 5.010;
 use strict;
@@ -10,6 +10,37 @@ use Log::Any '$log';
 
 use Org::Parser;
 
+our %common_args1 = (
+    file => {
+        schema => ['array*' => of => 'str*', min_len=>1],
+        req    => 1,
+        pos    => 0,
+        greedy => 1,
+        'x.schema.element_entity' => 'filename',
+    },
+    cache_dir => {
+        schema => ['str*'],
+        summary => 'Cache Org parse result',
+        description => <<'_',
+
+Since Org::Parser can spend some time to parse largish Org files, this is an
+option to store the parse result. Caching is turned on if this argument is set.
+
+_
+        'x.schema.entity' => 'dirname',
+    },
+    time_zone => {
+        schema => ['str'],
+        summary => 'Will be passed to parser\'s options',
+        description => <<'_',
+
+If not set, TZ environment variable will be picked as default.
+
+_
+        #'x.schema.entity' => 'timezone',
+    },
+);
+
 our $_complete_state = sub {
     use experimental 'smartmatch';
     require Complete::Util;
@@ -27,10 +58,10 @@ our $_complete_state = sub {
     my $args = $res->[2];
 
     # read org
-    return unless $args->{files} && @{ $args->{files} };
+    return unless $args->{file} && @{ $args->{file} };
     my $tz = $args->{time_zone} // $ENV{TZ} // "UTC";
     my %docs = App::OrgUtils::_load_org_files_with_cache(
-        [grep {-f} @{ $args->{files} }], $args->{cache_dir}, {time_zone=>$tz});
+        [grep {-f} @{ $args->{file} }], $args->{cache_dir}, {time_zone=>$tz});
 
     # get todo states
     my @states;
@@ -59,10 +90,10 @@ our $_complete_priority = sub {
     my $args = $res->[2];
 
     # read org
-    return unless $args->{files} && @{ $args->{files} };
+    return unless $args->{file} && @{ $args->{file} };
     my $tz = $args->{time_zone} // $ENV{TZ} // "UTC";
     my %docs = App::OrgUtils::_load_org_files_with_cache(
-        [grep {-f} @{ $args->{files} }], $args->{cache_dir}, {time_zone=>$tz});
+        [grep {-f} @{ $args->{file} }], $args->{cache_dir}, {time_zone=>$tz});
 
     # get priorities
     my @prios;
@@ -91,10 +122,10 @@ our $_complete_tags = sub {
     my $args = $res->[2];
 
     # read org
-    return unless $args->{files} && @{ $args->{files} };
+    return unless $args->{file} && @{ $args->{file} };
     my $tz = $args->{time_zone} // $ENV{TZ} // "UTC";
     my %docs = App::OrgUtils::_load_org_files_with_cache(
-        [grep {-f} @{ $args->{files} }], $args->{cache_dir}, {time_zone=>$tz});
+        [grep {-f} @{ $args->{file} }], $args->{cache_dir}, {time_zone=>$tz});
 
     # collect tags
     my @tags;
@@ -156,7 +187,7 @@ App::OrgUtils - Some utilities for Org documents
 
 =head1 VERSION
 
-This document describes version 0.27 of App::OrgUtils (from Perl distribution App-OrgUtils), released on 2015-03-30.
+This document describes version 0.28 of App::OrgUtils (from Perl distribution App-OrgUtils), released on 2015-04-01.
 
 =head1 DESCRIPTION
 
@@ -169,20 +200,15 @@ L<Org::Parser>
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUtils>.
+Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUtils>.=head1 SOURCE
 
-=head1 SOURCE
-
-Source repository is at L<https://github.com/sharyanto/perl-App-OrgUtils>.
-
-=head1 BUGS
+Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.=head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-OrgUtils>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
